@@ -8,6 +8,7 @@ import (
 	"os/exec"
 	"path"
 	"strings"
+	"time"
 )
 
 //go:embed default/*.toml
@@ -24,6 +25,7 @@ type Config struct {
 	OpLog     OpLogConfig       `toml:"oplog"`
 	Limit     int               `toml:"limit"`
 	Git       GitConfig         `toml:"git"`
+	Ssh       SshConfig         `toml:"ssh"`
 }
 
 type Color struct {
@@ -124,8 +126,13 @@ type UIConfig struct {
 	Colors map[string]Color `toml:"colors"`
 	// TODO(ilyagr): It might make sense to rename this to `auto_refresh_period` to match `--period` option
 	// once we have a mechanism to deprecate the old name softly.
-	AutoRefreshInterval int          `toml:"auto_refresh_interval"`
-	Tracer              TracerConfig `toml:"tracer"`
+	AutoRefreshInterval        int          `toml:"auto_refresh_interval"`
+	FlashMessageDisplaySeconds int          `toml:"flash_message_display_seconds"`
+	Tracer                     TracerConfig `toml:"tracer"`
+}
+
+func GetExpiringFlashMessageTimeout(c *Config) time.Duration {
+	return time.Duration(c.UI.FlashMessageDisplaySeconds) * time.Second
 }
 
 type RevisionsConfig struct {
@@ -283,3 +290,7 @@ func GetGitDefaultRemote(c *Config) string {
 	}
 	return remote
 }
+
+type SshConfig struct {
+	HijackAskpass bool `toml:"hijack_askpass"`
+}
