@@ -8,6 +8,7 @@ import (
 	"github.com/charmbracelet/bubbles/list"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/lipgloss"
+	"github.com/charmbracelet/x/cellbuf"
 	"github.com/idursun/jjui/internal/config"
 	"github.com/idursun/jjui/internal/jj"
 	"github.com/idursun/jjui/internal/ui/common"
@@ -53,7 +54,10 @@ type styles struct {
 	noRemoteStyle lipgloss.Style
 }
 
+var _ common.Model = (*Model)(nil)
+
 type Model struct {
+	*common.ViewNode
 	context           *context.MainContext
 	keymap            config.KeyMappings[key.Binding]
 	menu              menu.Menu
@@ -70,6 +74,9 @@ func (m *Model) ShortHelp() []key.Binding {
 		m.keymap.Git.Push,
 		m.keymap.Git.Fetch,
 		m.menu.List.KeyMap.Filter,
+		key.NewBinding(
+			key.WithKeys("tab/shift+tab"),
+			key.WithHelp("tab/shift+tab", "cycle remotes")),
 	}
 }
 
@@ -77,22 +84,6 @@ func (m *Model) FullHelp() [][]key.Binding {
 	return [][]key.Binding{m.ShortHelp()}
 }
 
-func (m *Model) Width() int {
-	return m.menu.Width()
-}
-
-func (m *Model) Height() int {
-	return m.menu.Height()
-}
-
-func (m *Model) SetWidth(w int) {
-	m.menu.SetWidth(w)
-}
-
-func (m *Model) SetHeight(h int) {
-	m.menu.SetHeight(h)
-}
-
 func (m *Model) Init() tea.Cmd {
 	return nil
 }
@@ -118,7 +109,7 @@ func (m *Model) cycleRemotes(step int) tea.Cmd {
 	return m.menu.List.SetItems(m.menu.Items)
 }
 
-func (m *Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
+func (m *Model) Update(msg tea.Msg) tea.Cmd {
 	switch msg := msg.(type) {
 	case tea.KeyMsg:
 		if m.menu.List.SettingFilter() {
@@ -126,18 +117,18 @@ func (m *Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		}
 		switch {
 		case msg.Type == tea.KeyTab:
-			return m, m.cycleRemotes(1)
+			return m.cycleRemotes(1)
 		case msg.Type == tea.KeyShiftTab:
-			return m, m.cycleRemotes(-1)
+			return m.cycleRemotes(-1)
 		case key.Matches(msg, m.keymap.Apply):
 			action := m.menu.List.SelectedItem().(item)
-			return m, m.context.RunCommand(jj.Args(action.command...), common.Refresh, common.Close)
+			return m.context.RunCommand(jj.Args(action.command...), common.Refresh, common.Close)
 		case key.Matches(msg, m.keymap.Cancel):
 			if m.menu.Filter != "" || m.menu.List.IsFiltered() {
 				m.menu.List.ResetFilter()
 				return m.filtered("")
 			}
-			return m, common.Close
+			return common.Close
 		case key.Matches(msg, m.keymap.Git.Push) && m.menu.Filter != string(itemCategoryPush):
 			return m.filtered(string(itemCategoryPush))
 		case key.Matches(msg, m.keymap.Git.Fetch) && m.menu.Filter != string(itemCategoryFetch):
@@ -145,22 +136,29 @@ func (m *Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		default:
 			for _, listItem := range m.menu.List.Items() {
 				if item, ok := listItem.(item); ok && m.menu.Filter != "" && item.key == msg.String() {
-					return m, m.context.RunCommand(jj.Args(item.command...), common.Refresh, common.Close)
+					return m.context.RunCommand(jj.Args(item.command...), common.Refresh, common.Close)
 				}
 			}
 		}
 	}
 	var cmd tea.Cmd
 	m.menu.List, cmd = m.menu.List.Update(msg)
-	return m, cmd
+	return cmd
 }
 
-func (m *Model) filtered(filter string) (tea.Model, tea.Cmd) {
-	return m, m.menu.Filtered(filter)
+func (m *Model) filtered(filter string) tea.Cmd {
+	return m.menu.Filtered(filter)
 }
 
 func (m *Model) View() string {
-	return m.menu.View()
+	pw, ph := m.Parent.Width, m.Parent.Height
+	m.menu.SetFrame(cellbuf.Rect(0, 0, min(pw, 80), min(ph, 40)).Inset(2))
+	v := m.menu.View()
+	w, h := lipgloss.Size(v)
+	sx := (pw - w) / 2
+	sy := (ph - h) / 2
+	m.SetFrame(cellbuf.Rect(sx, sy, w, h))
+	return v
 }
 
 func (m *Model) displayRemotes() string {
@@ -193,7 +191,7 @@ func loadRemoteNames(c context.CommandRunner) []string {
 	return remotes
 }
 
-func NewModel(c *context.MainContext, revisions jj.SelectedRevisions, width int, height int) *Model {
+func NewModel(c *context.MainContext, revisions jj.SelectedRevisions) *Model {
 	remotes := loadRemoteNames(c)
 	keymap := config.Current.GetKeyMap()
 
@@ -205,6 +203,7 @@ func NewModel(c *context.MainContext, revisions jj.SelectedRevisions, width int,
 	}
 
 	m := &Model{
+		ViewNode:          common.NewViewNode(0, 0),
 		context:           c,
 		keymap:            keymap,
 		revisions:         revisions,
@@ -214,7 +213,8 @@ func NewModel(c *context.MainContext, revisions jj.SelectedRevisions, width int,
 	}
 
 	items := m.createMenuItems()
-	m.menu = menu.NewMenu(items, width, height, m.keymap, menu.WithStylePrefix("git"))
+	m.menu = menu.NewMenu(items, m.keymap, menu.WithStylePrefix("git"))
+	m.menu.Parent = m.ViewNode
 	m.menu.Title = "Git Operations"
 	m.menu.Subtitle = m.displayRemotes()
 	m.menu.FilterMatches = func(i list.Item, filter string) bool {
@@ -224,8 +224,6 @@ func NewModel(c *context.MainContext, revisions jj.SelectedRevisions, width int,
 		return false
 	}
 
-	m.SetWidth(width)
-	m.SetHeight(height)
 	return m
 }
 
