@@ -2,6 +2,7 @@ package preview
 
 import (
 	"log"
+	"strconv"
 	"strings"
 	"time"
 
@@ -16,8 +17,10 @@ import (
 	"github.com/idursun/jjui/internal/ui/context"
 )
 
-const scrollAmount = 3
-const handleSize = 3
+const (
+	scrollAmount = 3
+	handleSize   = 3
+)
 
 var _ common.Model = (*Model)(nil)
 
@@ -37,8 +40,10 @@ type Model struct {
 	keyMap                  config.KeyMappings[key.Binding]
 }
 
-const debounceId = "preview-refresh"
-const debounceDuration = 50 * time.Millisecond
+const (
+	debounceId       = "preview-refresh"
+	debounceDuration = 50 * time.Millisecond
+)
 
 type previewMsg struct {
 	msg tea.Msg
@@ -169,13 +174,14 @@ func (m *Model) Update(msg tea.Msg) tea.Cmd {
 	}
 	switch msg := msg.(type) {
 	case tea.MouseMsg:
-		if msg.Button == tea.MouseButtonWheelUp {
+		switch msg.Button {
+		case tea.MouseButtonWheelUp:
 			m.Scroll(-scrollAmount)
-		} else if msg.Button == tea.MouseButtonWheelDown {
+		case tea.MouseButtonWheelDown:
 			m.Scroll(scrollAmount)
-		} else if msg.Button == tea.MouseButtonWheelLeft {
+		case tea.MouseButtonWheelLeft:
 			m.ScrollHorizontal(-scrollAmount)
-		} else if msg.Button == tea.MouseButtonWheelRight {
+		case tea.MouseButtonWheelRight:
 			m.ScrollHorizontal(scrollAmount)
 		}
 	case common.SelectionChangedMsg, common.RefreshMsg:
@@ -216,24 +222,28 @@ func (m *Model) reset() {
 func (m *Model) refreshPreview() tea.Cmd {
 	return common.Debounce(debounceId, debounceDuration, func() tea.Msg {
 		var args []string
+		previewWidth := strconv.Itoa(m.view.Width)
 		switch msg := m.context.SelectedItem.(type) {
 		case context.SelectedFile:
 			args = jj.TemplatedArgs(config.Current.Preview.FileCommand, map[string]string{
-				jj.RevsetPlaceholder:   m.context.CurrentRevset,
-				jj.ChangeIdPlaceholder: msg.ChangeId,
-				jj.CommitIdPlaceholder: msg.CommitId,
-				jj.FilePlaceholder:     msg.File,
+				jj.RevsetPlaceholder:       m.context.CurrentRevset,
+				jj.ChangeIdPlaceholder:     msg.ChangeId,
+				jj.CommitIdPlaceholder:     msg.CommitId,
+				jj.FilePlaceholder:         msg.File,
+				jj.PreviewWidthPlaceholder: previewWidth,
 			})
 		case context.SelectedRevision:
 			args = jj.TemplatedArgs(config.Current.Preview.RevisionCommand, map[string]string{
-				jj.RevsetPlaceholder:   m.context.CurrentRevset,
-				jj.ChangeIdPlaceholder: msg.ChangeId,
-				jj.CommitIdPlaceholder: msg.CommitId,
+				jj.RevsetPlaceholder:       m.context.CurrentRevset,
+				jj.ChangeIdPlaceholder:     msg.ChangeId,
+				jj.CommitIdPlaceholder:     msg.CommitId,
+				jj.PreviewWidthPlaceholder: previewWidth,
 			})
 		case context.SelectedOperation:
 			args = jj.TemplatedArgs(config.Current.Preview.OplogCommand, map[string]string{
-				jj.RevsetPlaceholder:      m.context.CurrentRevset,
-				jj.OperationIdPlaceholder: msg.OperationId,
+				jj.RevsetPlaceholder:       m.context.CurrentRevset,
+				jj.OperationIdPlaceholder:  msg.OperationId,
+				jj.PreviewWidthPlaceholder: previewWidth,
 			})
 		}
 
