@@ -31,7 +31,10 @@ const (
 	commandFailed
 )
 
+var _ common.Model = (*Model)(nil)
+
 type Model struct {
+	*common.ViewNode
 	context    *context.MainContext
 	spinner    spinner.Model
 	input      textinput.Model
@@ -39,7 +42,6 @@ type Model struct {
 	command    string
 	status     commandStatus
 	running    bool
-	width      int
 	mode       string
 	editStatus editStatus
 	history    map[string][]string
@@ -79,24 +81,11 @@ const CommandClearDuration = 3 * time.Second
 
 type clearMsg string
 
-func (m *Model) Width() int {
-	return m.width
-}
-
-func (m *Model) Height() int {
-	return 1
-}
-
-func (m *Model) SetWidth(w int) {
-	m.width = w
-}
-
-func (m *Model) SetHeight(int) {}
 func (m *Model) Init() tea.Cmd {
 	return nil
 }
 
-func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
+func (m *Model) Update(msg tea.Msg) tea.Cmd {
 	km := config.Current.GetKeyMap()
 	switch msg := msg.(type) {
 	case clearMsg:
@@ -104,11 +93,11 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 			m.command = ""
 			m.status = none
 		}
-		return m, nil
+		return nil
 	case common.CommandRunningMsg:
 		m.command = string(msg)
 		m.status = commandRunning
-		return m, m.spinner.Tick
+		return m.spinner.Tick
 	case common.CommandCompletedMsg:
 		if msg.Err != nil {
 			m.status = commandFailed
@@ -116,7 +105,7 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 			m.status = commandCompleted
 		}
 		commandToBeCleared := m.command
-		return m, tea.Tick(CommandClearDuration, func(time.Time) tea.Msg {
+		return tea.Tick(CommandClearDuration, func(time.Time) tea.Msg {
 			return clearMsg(commandToBeCleared)
 		})
 	case common.FileSearchMsg:
@@ -124,7 +113,21 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 		m.input.Prompt = "> "
 		m.loadEditingSuggestions()
 		m.fuzzy, m.editStatus = fuzzy_files.NewModel(msg)
-		return m, tea.Batch(m.fuzzy.Init(), m.input.Focus())
+		return tea.Batch(m.fuzzy.Init(), m.input.Focus())
+	case common.ExecProcessCompletedMsg:
+		if msg.Err != nil {
+			m.mode = "exec " + msg.Msg.Mode.Mode
+			m.input.Prompt = msg.Msg.Mode.Prompt
+			m.loadEditingSuggestions()
+			m.fuzzy, m.editStatus = fuzzy_input.NewModel(&m.input, m.input.AvailableSuggestions())
+
+			// Avoid to change the current behavior when coming back from exec process
+			focusCmd := m.input.Focus()
+			keyMsg := tea.KeyMsg{Type: tea.KeyRunes, Runes: []rune(msg.Msg.Line)}
+			updateCmd := m.Update(keyMsg)
+			return tea.Batch(m.fuzzy.Init(), focusCmd, updateCmd)
+		}
+		return nil
 	case tea.KeyMsg:
 		switch {
 		case key.Matches(msg, km.Cancel) && m.IsFocused():
@@ -136,12 +139,20 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 			m.fuzzy = nil
 			m.editStatus = nil
 			m.input.Reset()
-			return m, cmd
+			return cmd
 		case key.Matches(msg, accept) && m.IsFocused():
 			editMode := m.mode
 			input := m.input.Value()
 			prompt := m.input.Prompt
 			fuzzy := m.fuzzy
+			// If there's a selected match in the fuzzy list, use that instead
+			if fuzzy != nil {
+				if selected := fuzzy_search.SelectedMatch(fuzzy); selected != "" {
+					// SelectedMatch returns the value wrapped in single quotes, remove them
+					input = strings.Trim(selected, "'")
+					m.input.SetValue(input)
+				}
+			}
 			m.saveEditingSuggestions()
 
 			m.fuzzy = nil
@@ -153,11 +164,11 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 			switch {
 			case strings.HasSuffix(editMode, "file"):
 				_, cmd := fuzzy.Update(msg)
-				return m, cmd
+				return cmd
 			case strings.HasPrefix(editMode, "exec"):
-				return m, func() tea.Msg { return exec_process.ExecMsgFromLine(prompt, input) }
+				return func() tea.Msg { return exec_process.ExecMsgFromLine(prompt, input) }
 			}
-			return m, func() tea.Msg { return common.QuickSearchMsg(input) }
+			return func() tea.Msg { return common.QuickSearchMsg(input) }
 		case key.Matches(msg, km.ExecJJ, km.ExecShell) && !m.IsFocused():
 			mode := common.ExecJJ
 			if key.Matches(msg, km.ExecShell) {
@@ -168,13 +179,13 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 			m.loadEditingSuggestions()
 
 			m.fuzzy, m.editStatus = fuzzy_input.NewModel(&m.input, m.input.AvailableSuggestions())
-			return m, tea.Batch(m.fuzzy.Init(), m.input.Focus())
+			return tea.Batch(m.fuzzy.Init(), m.input.Focus())
 		case key.Matches(msg, km.QuickSearch) && !m.IsFocused():
 			m.editStatus = emptyEditStatus
 			m.mode = "search"
 			m.input.Prompt = "> "
 			m.loadEditingSuggestions()
-			return m, m.input.Focus()
+			return m.input.Focus()
 		default:
 			if m.IsFocused() {
 				var cmd tea.Cmd
@@ -182,10 +193,10 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 				if m.fuzzy != nil {
 					cmd = tea.Batch(cmd, fuzzy_search.Search(m.input.Value(), msg))
 				}
-				return m, cmd
+				return cmd
 			}
 		}
-		return m, nil
+		return nil
 	default:
 		var cmd tea.Cmd
 		if m.status == commandRunning {
@@ -194,7 +205,7 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 		if m.fuzzy != nil {
 			m.fuzzy, cmd = fuzzy_search.Update(m.fuzzy, msg)
 		}
-		return m, cmd
+		return cmd
 	}
 }
 
@@ -224,9 +235,9 @@ func (m *Model) View() string {
 		commandStatusMark = m.styles.success.Render("✓ ")
 	} else {
 		commandStatusMark = m.helpView(m.keyMap)
-		commandStatusMark = lipgloss.PlaceHorizontal(m.width, 0, commandStatusMark, lipgloss.WithWhitespaceBackground(m.styles.text.GetBackground()))
+		commandStatusMark = lipgloss.PlaceHorizontal(m.Width, 0, commandStatusMark, lipgloss.WithWhitespaceBackground(m.styles.text.GetBackground()))
 	}
-	modeWith := 11
+	modeWith := max(10, len(m.mode)+2)
 	ret := m.styles.text.Render(strings.ReplaceAll(m.command, "\n", "⏎"))
 	if m.IsFocused() {
 		commandStatusMark = ""
@@ -235,13 +246,13 @@ func (m *Model) View() string {
 			editHelp = lipgloss.JoinHorizontal(0, m.helpView(editKeys), editHelp)
 		}
 		promptWidth := len(m.input.Prompt) + 2
-		m.input.Width = m.width - modeWith - promptWidth - lipgloss.Width(editHelp)
+		m.input.Width = m.Width - modeWith - promptWidth - lipgloss.Width(editHelp)
 		ret = lipgloss.JoinHorizontal(0, m.input.View(), editHelp)
 	}
 	mode := m.styles.title.Width(modeWith).Render("", m.mode)
 	ret = lipgloss.JoinHorizontal(lipgloss.Left, mode, m.styles.text.Render(" "), commandStatusMark, ret)
 	height := lipgloss.Height(ret)
-	return lipgloss.Place(m.width, height, 0, 0, ret, lipgloss.WithWhitespaceBackground(m.styles.text.GetBackground()))
+	return lipgloss.Place(m.Width, height, 0, 0, ret, lipgloss.WithWhitespaceBackground(m.styles.text.GetBackground()))
 }
 
 func (m *Model) SetHelp(keyMap help.KeyMap) {
@@ -268,7 +279,7 @@ func (m *Model) helpView(keyMap help.KeyMap) string {
 	return help
 }
 
-func New(context *context.MainContext) Model {
+func New(context *context.MainContext) *Model {
 	styles := styles{
 		shortcut: common.DefaultPalette.Get("status shortcut"),
 		dimmed:   common.DefaultPalette.Get("status dimmed"),
@@ -286,13 +297,14 @@ func New(context *context.MainContext) Model {
 	t.CompletionStyle = styles.dimmed
 	t.PlaceholderStyle = styles.dimmed
 
-	return Model{
-		context: context,
-		spinner: s,
-		command: "",
-		status:  none,
-		input:   t,
-		keyMap:  nil,
-		styles:  styles,
+	return &Model{
+		ViewNode: common.NewViewNode(0, 0),
+		context:  context,
+		spinner:  s,
+		command:  "",
+		status:   none,
+		input:    t,
+		keyMap:   nil,
+		styles:   styles,
 	}
 }
