@@ -10,6 +10,7 @@ import (
 	"github.com/idursun/jjui/internal/scripting"
 	"github.com/idursun/jjui/internal/ui/intents"
 	"github.com/idursun/jjui/internal/ui/layout"
+	"github.com/idursun/jjui/internal/ui/password"
 
 	"github.com/idursun/jjui/internal/ui/flash"
 
@@ -19,6 +20,7 @@ import (
 	"github.com/idursun/jjui/internal/config"
 	"github.com/idursun/jjui/internal/jj"
 	"github.com/idursun/jjui/internal/ui/bookmarks"
+	"github.com/idursun/jjui/internal/ui/choose"
 	"github.com/idursun/jjui/internal/ui/common"
 	"github.com/idursun/jjui/internal/ui/context"
 	customcommands "github.com/idursun/jjui/internal/ui/custom_commands"
@@ -26,6 +28,7 @@ import (
 	"github.com/idursun/jjui/internal/ui/exec_process"
 	"github.com/idursun/jjui/internal/ui/git"
 	"github.com/idursun/jjui/internal/ui/helppage"
+	"github.com/idursun/jjui/internal/ui/input"
 	"github.com/idursun/jjui/internal/ui/leader"
 	"github.com/idursun/jjui/internal/ui/oplog"
 	"github.com/idursun/jjui/internal/ui/preview"
@@ -54,6 +57,7 @@ type Model struct {
 	flash           *flash.Model
 	state           common.State
 	status          *status.Model
+	password        *password.Model
 	context         *context.MainContext
 	scriptRunner    *scripting.Runner
 	keyMap          config.KeyMappings[key.Binding]
@@ -95,6 +99,10 @@ func (m *Model) handleFocusInputMessage(msg tea.Msg) (tea.Cmd, bool) {
 
 	switch msg := msg.(type) {
 	case tea.KeyMsg:
+		if m.password != nil {
+			return m.password.Update(msg), true
+		}
+
 		if m.diff != nil {
 			return m.diff.Update(msg), true
 		}
@@ -360,10 +368,38 @@ func (m *Model) Update(msg tea.Msg) tea.Cmd {
 			m.scriptRunner = nil
 		}
 		return cmd
+	case common.ShowChooseMsg:
+		model := choose.NewWithTitle(msg.Options, msg.Title)
+		model.Parent = m.ViewNode
+		m.stacked = model
+		return m.stacked.Init()
+	case choose.SelectedMsg, choose.CancelledMsg:
+		m.stacked = nil
+	case common.ShowInputMsg:
+		model := input.NewWithTitle(msg.Title, msg.Prompt)
+		model.Parent = m.ViewNode
+		m.stacked = model
+		return m.stacked.Init()
+	case input.SelectedMsg, input.CancelledMsg:
+		m.stacked = nil
 	case common.ShowPreview:
 		m.previewModel.SetVisible(bool(msg))
 		cmds = append(cmds, common.SelectionChanged)
 		return tea.Batch(cmds...)
+	case common.TogglePasswordMsg:
+		if m.password != nil {
+			// let the current prompt clean itself
+			m.password.Update(msg)
+		}
+		if msg.Password == nil {
+			m.password = nil
+		} else {
+			// overwrite current prompt. This can happen for ssh-sk keys:
+			//   - first prompt reads "Confirm user presence for ..."
+			//   - if the user denies the request on the device, a new prompt automatically happen "Enter PIN for ...
+			m.password = password.New(msg, m.ViewNode)
+		}
+
 	case tea.WindowSizeMsg:
 		m.SetFrame(cellbuf.Rect(0, 0, msg.Width, msg.Height))
 		m.flash.SetWidth(m.Width)
@@ -501,6 +537,11 @@ func (m *Model) View() string {
 		cellbuf.SetContentRect(screenBuf, statusFuzzyView, cellbuf.Rect(0, m.Height-mh-1, m.Width, mh))
 	}
 
+	if m.password != nil {
+		view := m.password.View()
+		cellbuf.SetContentRect(screenBuf, view, m.password.Frame)
+	}
+
 	finalView := cellbuf.Render(screenBuf)
 	return strings.ReplaceAll(finalView, "\r", "")
 }
@@ -548,13 +589,15 @@ func (m *Model) findViewAt(x, y int) common.IMouseAware {
 
 var _ tea.Model = (*wrapper)(nil)
 
-type frameTickMsg struct{}
-type wrapper struct {
-	ui                 *Model
-	scheduledNextFrame bool
-	render             bool
-	cachedFrame        string
-}
+type (
+	frameTickMsg struct{}
+	wrapper      struct {
+		ui                 *Model
+		scheduledNextFrame bool
+		render             bool
+		cachedFrame        string
+	}
+)
 
 func (w *wrapper) Init() tea.Cmd {
 	return w.ui.Init()
